@@ -66,6 +66,8 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
+		inten = jsonInput['outcome']['entities']['body']
+ 		log.msg("inten :  %s" % (inten)
 		if jsonInput['outcome']['entities']['location']['body'] :
 			location = jsonInput['outcome']['entities']['location']['body']
 		else:
